@@ -29,6 +29,7 @@ api_watchlist <- function(RH, watchlist_url, detail = FALSE, delete = FALSE) {
                            "Content-Type" = "application/json",
                            "Authorization" = token),
                config(customrequest = "DELETE"))
+    httr::stop_for_status(dta)
 
     dta <- rawToChar(dta$content)
 
@@ -42,8 +43,9 @@ api_watchlist <- function(RH, watchlist_url, detail = FALSE, delete = FALSE) {
                add_headers("Accept" = "application/json",
                            "Content-Type" = "application/json",
                            "Authorization" = token))
+    httr::stop_for_status(dta)
 
-    dta <- mod_json(dta, "fromJSON")
+    dta <- RobinHood::mod_json(dta, "fromJSON")
 
   }
 
@@ -56,8 +58,9 @@ api_watchlist <- function(RH, watchlist_url, detail = FALSE, delete = FALSE) {
                             "Content-Type" = "application/json",
                             "Authorization" = token),
                 body = mod_json(detail, "toJSON"))
+    httr::stop_for_status(dta)
 
-    dta <- mod_json(dta, "fromJSON")
+    dta <- RobinHood::mod_json(dta, "fromJSON")
 
   }
 
