@@ -26,9 +26,9 @@
 #'}
 cancel_order <- function(RH, cancel_url) {
 
-  check_rh(RH)
+  RobinHood::check_rh(RH)
 
-  order_status <- api_orders(RH, action = "cancel", cancel_url = cancel_url)
+  order_status <- RobinHood::api_orders(RH, action = "cancel", cancel_url = cancel_url)
 
   if (length(order_status) == 0) cat("Order Canceled")
 
