@@ -13,10 +13,10 @@
 get_accounts <- function(RH) {
 
     # Check if RH is valid
-    check_rh(RH)
+    RobinHood::check_rh(RH)
 
     # Pull RH account data
-    accounts <- api_accounts(RH)
+    accounts <- RobinHood::api_accounts(RH)
 
     return(accounts)
 
