@@ -14,16 +14,16 @@
 get_order_history <- function(RH, page_size = 1000) {
 
     # Check if RH is valid
-    check_rh(RH)
+    RobinHood::check_rh(RH)
 
     # Get Order History
-    order_history <- api_orders(RH, action = "history", page_size = page_size)
+    order_history <- RobinHood::api_orders(RH, action = "history", page_size = page_size)
 
     # Get symbol to attach to output
     symbol <- as.character()
 
     for (i in order_history$instrument) {
-      x <- api_instruments(RH, instrument_url = i)
+      x <- RobinHood::api_instruments(RH, instrument_url = i)
       x <- x$symbol
       symbol <- c(symbol, x)
     }
@@ -44,8 +44,8 @@ get_order_history <- function(RH, page_size = 1000) {
                                        "updated_at")]
 
   # Format timestamp
-  order_history$created_at <-  lubridate::ymd_hms(order_history$created_at)
-  order_history$updated_at <-  lubridate::ymd_hms(order_history$updated_at)
+  order_history$created_at <- lubridate::ymd_hms(order_history$created_at)
+  order_history$updated_at <- lubridate::ymd_hms(order_history$updated_at)
   order_history$fees <- as.numeric(order_history$fees)
   order_history$price <- as.numeric(order_history$price)
   order_history$average_price <- as.numeric(order_history$average_price)
